Arithmetic networks
-------------------

The file ``mockturtle/generators/arithmetic.hpp`` implements several functions
to generate arithmetic networks.

Addition and Subtraction
~~~~~~~~~~~~~~~~~~~~~~~~

.. doxygenfunction:: mockturtle::full_adder
.. doxygenfunction:: mockturtle::carry_ripple_adder_inplace
.. doxygenfunction:: mockturtle::carry_ripple_subtractor_inplace
.. doxygenfunction:: mockturtle::carry_ripple_multiplier
.. doxygenfunction:: mockturtle::carry_lookahead_adder_inplace
.. doxygenfunction:: mockturtle::sideways_sum_adder
